@@ -3,12 +3,12 @@ package clihandler
 import (
 	"fmt"
 	"os"
-	"strings"
 
 	"github.com/armosec/armoapi-go/armotypes"
 	"github.com/armosec/k8s-interface/k8sinterface"
 	"github.com/armosec/kubescape/cautils"
 	"github.com/armosec/kubescape/cautils/getter"
+	"github.com/armosec/kubescape/clihandler/cliinterfaces"
 	"github.com/armosec/kubescape/opaprocessor"
 	"github.com/armosec/kubescape/policyhandler"
 	"github.com/armosec/kubescape/resourcehandler"
@@ -16,16 +16,9 @@ import (
 	"github.com/armosec/kubescape/resultshandling/printer"
 	"github.com/armosec/kubescape/resultshandling/reporter"
 	"github.com/armosec/opa-utils/reporthandling"
+	"github.com/golang/glog"
 )
 
-type CLIHandler struct {
-	policyHandler *policyhandler.PolicyHandler
-	scanInfo      *cautils.ScanInfo
-}
-
-var SupportedFrameworks = []string{"nsa", "mitre"}
-var ValidFrameworks = strings.Join(SupportedFrameworks, ", ")
-
 type componentInterfaces struct {
 	clusterConfig   cautils.IClusterConfig
 	resourceHandler resourcehandler.IResourceHandler
@@ -41,12 +34,24 @@ func getReporter(scanInfo *cautils.ScanInfo) reporter.IReport {
 		return reporter.NewReportMock()
 	}
 
-	return reporter.NewReportEventReceiver()
+	return reporter.NewReportEventReceiver("", "")
+}
+
+func getFieldSelector(scanInfo *cautils.ScanInfo) resourcehandler.IFieldSelector {
+	if scanInfo.IncludeNamespaces != "" {
+		return resourcehandler.NewIncludeSelector(scanInfo.IncludeNamespaces)
+	}
+	if scanInfo.ExcludedNamespaces != "" {
+		return resourcehandler.NewExcludeSelector(scanInfo.ExcludedNamespaces)
+	}
+
+	return &resourcehandler.EmptySelector{}
 }
 func getInterfaces(scanInfo *cautils.ScanInfo) componentInterfaces {
 	var resourceHandler resourcehandler.IResourceHandler
 	var clusterConfig cautils.IClusterConfig
 	var reportHandler reporter.IReport
+	var scanningTarget string
 
 	if !scanInfo.ScanRunningCluster() {
 		k8sinterface.ConnectedToCluster = false
@@ -57,15 +62,20 @@ func getInterfaces(scanInfo *cautils.ScanInfo) componentInterfaces {
 
 		// set mock report (do not send report)
 		reportHandler = reporter.NewReportMock()
+		scanningTarget = "yaml"
 	} else {
 		k8s := k8sinterface.NewKubernetesApi()
-		resourceHandler = resourcehandler.NewK8sResourceHandler(k8s, scanInfo.ExcludedNamespaces)
+		resourceHandler = resourcehandler.NewK8sResourceHandler(k8s, getFieldSelector(scanInfo))
 		clusterConfig = cautils.ClusterConfigSetup(scanInfo, k8s, getter.GetArmoAPIConnector())
 
 		// setup reporter
 		reportHandler = getReporter(scanInfo)
+		scanningTarget = "cluster"
 	}
 
+	v := cautils.NewIVersionCheckHandler()
+	v.CheckLatestVersion(cautils.NewVersionCheckRequest(cautils.BuildNumber, "", "", scanningTarget))
+
 	// setup printer
 	printerHandler := printer.GetPrinter(scanInfo.Format)
 	printerHandler.SetWriter(scanInfo.Output)
@@ -77,11 +87,34 @@ func getInterfaces(scanInfo *cautils.ScanInfo) componentInterfaces {
 		printerHandler:  printerHandler,
 	}
 }
+func setPolicyGetter(scanInfo *cautils.ScanInfo, customerGUID string) {
+	if len(scanInfo.UseFrom) > 0 {
+		//load from file
+		scanInfo.PolicyGetter = getter.NewLoadPolicy(scanInfo.UseFrom)
+	} else {
+		if customerGUID == "" || !scanInfo.FrameworkScan {
+			scanInfo.PolicyGetter = getter.NewDownloadReleasedPolicy()
+		} else {
+			g := getter.GetArmoAPIConnector()
+			g.SetCustomerGUID(customerGUID)
+			scanInfo.PolicyGetter = g
+			if scanInfo.ScanAll {
+				frameworks, err := g.ListCustomFrameworks(customerGUID)
+				if err != nil {
+					glog.Error("could not get custom frameworks")
+				}
+				scanInfo.SetPolicyIdentifierForGivenFrameworks(frameworks)
+			}
+		}
+	}
+}
 
-func CliSetup(scanInfo *cautils.ScanInfo) error {
+func ScanCliSetup(scanInfo *cautils.ScanInfo) error {
 
 	interfaces := getInterfaces(scanInfo)
 
+	setPolicyGetter(scanInfo, interfaces.clusterConfig.GetCustomerGUID())
+
 	processNotification := make(chan *cautils.OPASessionObj)
 	reportResults := make(chan *cautils.OPASessionObj)
 
@@ -97,8 +130,8 @@ func CliSetup(scanInfo *cautils.ScanInfo) error {
 	go func() {
 		// policy handler setup
 		policyHandler := policyhandler.NewPolicyHandler(&processNotification, interfaces.resourceHandler)
-		cli := NewCLIHandler(policyHandler, scanInfo)
-		if err := cli.Scan(); err != nil {
+
+		if err := Scan(policyHandler, scanInfo); err != nil {
 			fmt.Println(err)
 			os.Exit(1)
 		}
@@ -118,31 +151,22 @@ func CliSetup(scanInfo *cautils.ScanInfo) error {
 
 	adjustedFailThreshold := float32(scanInfo.FailThreshold) / 100
 	if score < adjustedFailThreshold {
-		return fmt.Errorf("Scan score is bellow threshold")
+		return fmt.Errorf("Scan score is below threshold")
 	}
 
 	return nil
 }
 
-func NewCLIHandler(policyHandler *policyhandler.PolicyHandler, scanInfo *cautils.ScanInfo) *CLIHandler {
-	return &CLIHandler{
-		scanInfo:      scanInfo,
-		policyHandler: policyHandler,
-	}
-}
-
-func (clihandler *CLIHandler) Scan() error {
+func Scan(policyHandler *policyhandler.PolicyHandler, scanInfo *cautils.ScanInfo) error {
 	cautils.ScanStartDisplay()
 	policyNotification := &reporthandling.PolicyNotification{
 		NotificationType: reporthandling.TypeExecPostureScan,
-		Rules: []reporthandling.PolicyIdentifier{
-			clihandler.scanInfo.PolicyIdentifier,
-		},
-		Designators: armotypes.PortalDesignator{},
+		Rules:            scanInfo.PolicyIdentifier,
+		Designators:      armotypes.PortalDesignator{},
 	}
 	switch policyNotification.NotificationType {
 	case reporthandling.TypeExecPostureScan:
-		if err := clihandler.policyHandler.HandleNotificationRequest(policyNotification, clihandler.scanInfo); err != nil {
+		if err := policyHandler.HandleNotificationRequest(policyNotification, scanInfo); err != nil {
 			return err
 		}
 
@@ -151,3 +175,21 @@ func (clihandler *CLIHandler) Scan() error {
 	}
 	return nil
 }
+
+func Submit(submitInterfaces cliinterfaces.SubmitInterfaces) error {
+
+	// list resources
+	postureReport, err := submitInterfaces.SubmitObjects.SetResourcesReport()
+	if err != nil {
+		return err
+	}
+
+	// report
+	if err := submitInterfaces.Reporter.ActionSendReport(&cautils.OPASessionObj{PostureReport: postureReport}); err != nil {
+		return err
+	}
+	fmt.Printf("\nData has been submitted successfully")
+	submitInterfaces.ClusterConfig.GenerateURL()
+
+	return nil
+}
