@@ -8,7 +8,9 @@ type ReportMock struct {
 func NewReportMock() *ReportMock {
 	return &ReportMock{}
 }
-func (reportMock *ReportMock) ActionSendReport(opaSessionObj *cautils.OPASessionObj) {}
+func (reportMock *ReportMock) ActionSendReport(opaSessionObj *cautils.OPASessionObj) error {
+	return nil
+}
 
 func (reportMock *ReportMock) SetCustomerGUID(customerGUID string) {
 }
